@@ -55,7 +55,7 @@ sub attributes {
 		$a->IMAGE,
 		$a->TOC,
 		$a->FORM,
-		$a->INPUT
+		$a->INPUT,
 	);
 }
 
